package com.community.huiju.service.impl;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.community.commom.mode.ResponseBean;
import com.community.commom.session.UserElement;
import com.community.huiju.dao.RoleMapper;
import com.community.huiju.dao.SysRoleMenuMapper;
import com.community.huiju.model.SysRole;
import com.community.huiju.model.SysRoleMenu;
import com.community.huiju.model.TpTransaction;
import com.community.huiju.service.RoleServiceI;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author FXF
 * @date 2019-01-16
 */
@Service("roleService")
@Slf4j
public class RoleServiceImpl extends ServiceImpl<RoleMapper, SysRole> implements RoleServiceI {
	
	@Autowired
	private RoleMapper roleMapper;
	
	@Autowired
	private SysRoleMenuMapper sysRoleMenuMapper;
	/**
	 * 获取角色列表
	 *
	 * @param roleName
	 * @param userElement
	 * @param pageNum
	 * @param pageSize
	 * @return
	 */
	@Override
	public ResponseBean getRoleList(String roleName, UserElement userElement, Integer pageNum, Integer pageSize) {
		ResponseBean responseBean = new ResponseBean();
		Page page = new Page(pageNum,pageSize);
		// 分页查询
		SysRole role = new SysRole();
		role.setRoleName(roleName);
		role.setCommunityId(userElement.getCommunityId());
		List<SysRole> list = roleMapper.getRoleListByParams(page,role);
		Map<String, Object> map = Maps.newHashMap();
		map.put("list",list);
		map.put("total",page.getTotal());
		responseBean.addSuccess(map);
		return responseBean;
	}
	
	/**
	 * 添加角色
	 *
	 * @param sysRole
	 * @param userElement
	 * @return
	 */
	@Override
	public ResponseBean addRole(SysRole sysRole, UserElement userElement) {
		ResponseBean responseBean = new ResponseBean();
		//接收数据
		sysRole.setCommunityId(userElement.getCommunityId());
		Integer userId = userElement.getId();
		LocalDateTime dateTime = LocalDateTime.now();
		sysRole.setCreateUser(userId);
		sysRole.setCreateDate(dateTime);
		sysRole.setUpdateUser(userId);
		sysRole.setUpdateDate(dateTime);
		//插入角色表
		int size = roleMapper.insert(sysRole);
		if (size < 1){
			responseBean.addError("插入失败");
			return responseBean;
		}
		//维护角色与menu的关系表
		List<SysRoleMenu> sysRoleMenuList = new ArrayList<SysRoleMenu>();
		List<Integer> menuIdList = sysRole.getMenuArray();
		menuIdList.stream().forEach(menuId -> {
			SysRoleMenu sysRoleMenu = new SysRoleMenu();
			sysRoleMenu.setCommunityId(userElement.getCommunityId());
			sysRoleMenu.setRoleId(sysRole.getId());
			sysRoleMenu.setMenuId(menuId);
			sysRoleMenuList.add(sysRoleMenu);
		});
		int count = sysRoleMenuMapper.insertList(sysRoleMenuList);
		if (count < 1){
			responseBean.addError("插入失败");
			return responseBean;
		}
		responseBean.addSuccess(size);
		return responseBean;
	}
}
